@@ -26,17 +26,18 @@ from typing import TYPE_CHECKING, cast, overload
 from weakref import ref as weak_ref
 
 from .dbus_common_elements import (
-    DbusBindedAsync,
+    DbusBoundAsync,
+    DbusMemberAsync,
     DbusMethodCommon,
     DbusMethodOverride,
     DbusRemoteObjectMeta,
-    DbusSomethingAsync,
 )
 from .dbus_exceptions import DbusFailedError
-from .sd_bus_internals import DbusNoReplyFlag
+from .sd_bus_internals import EXCEPTION_TO_DBUS_ERROR, DbusNoReplyFlag
 
 if TYPE_CHECKING:
-    from typing import Any, Callable, Optional, Sequence, Type, TypeVar, Union
+    from collections.abc import Callable, Sequence
+    from typing import Any, Optional, TypeVar, Union
 
     from .dbus_proxy_async_interface_base import DbusInterfaceBaseAsync
     from .sd_bus_internals import SdBusMessage
@@ -52,13 +53,13 @@ def get_current_message() -> SdBusMessage:
     return CURRENT_MESSAGE.get()
 
 
-class DbusMethodAsync(DbusMethodCommon, DbusSomethingAsync):
+class DbusMethodAsync(DbusMethodCommon, DbusMemberAsync):
 
     @overload
     def __get__(
         self,
         obj: None,
-        obj_class: Type[DbusInterfaceBaseAsync],
+        obj_class: type[DbusInterfaceBaseAsync],
     ) -> DbusMethodAsync:
         ...
 
@@ -66,32 +67,32 @@ class DbusMethodAsync(DbusMethodCommon, DbusSomethingAsync):
     def __get__(
         self,
         obj: DbusInterfaceBaseAsync,
-        obj_class: Type[DbusInterfaceBaseAsync],
+        obj_class: type[DbusInterfaceBaseAsync],
     ) -> Callable[..., Any]:
         ...
 
     def __get__(
         self,
         obj: Optional[DbusInterfaceBaseAsync],
-        obj_class: Optional[Type[DbusInterfaceBaseAsync]] = None,
+        obj_class: Optional[type[DbusInterfaceBaseAsync]] = None,
     ) -> Union[Callable[..., Any], DbusMethodAsync]:
         if obj is not None:
             dbus_meta = obj._dbus
             if isinstance(dbus_meta, DbusRemoteObjectMeta):
-                return DbusMethodAsyncProxyBind(self, dbus_meta)
+                return DbusProxyMethodAsync(self, dbus_meta)
             else:
-                return DbusMethodAsyncLocalBind(self, obj)
+                return DbusLocalMethodAsync(self, obj)
         else:
             return self
 
 
-class DbusMethodAsyncBaseBind(DbusBindedAsync):
+class DbusBoundMethodAsyncBase(DbusBoundAsync):
 
     def __call__(self, *args: Any, **kwargs: Any) -> Any:
         raise NotImplementedError
 
 
-class DbusMethodAsyncProxyBind(DbusMethodAsyncBaseBind):
+class DbusProxyMethodAsync(DbusBoundMethodAsyncBase):
     def __init__(
         self,
         dbus_method: DbusMethodAsync,
@@ -145,7 +146,7 @@ class DbusMethodAsyncProxyBind(DbusMethodAsyncBaseBind):
         return self._dbus_async_call(new_call_message)
 
 
-class DbusMethodAsyncLocalBind(DbusMethodAsyncBaseBind):
+class DbusLocalMethodAsync(DbusBoundMethodAsyncBase):
     def __init__(
         self,
         dbus_method: DbusMethodAsync,
@@ -192,23 +193,20 @@ class DbusMethodAsyncLocalBind(DbusMethodAsyncBaseBind):
                 request_message,
                 local_object,
             )
-        except DbusFailedError as e:
+        except Exception as e:
             if not request_message.expect_reply:
                 return
 
+            dbus_error = EXCEPTION_TO_DBUS_ERROR.get(type(e))
+            if dbus_error is None:
+                dbus_error = DbusFailedError.dbus_error_name
+
             error_message = request_message.create_error_reply(
-                e.dbus_error_name,
+                dbus_error,
                 str(e.args[0]) if e.args else "",
             )
             error_message.send()
             return
-        except Exception:
-            error_message = request_message.create_error_reply(
-                DbusFailedError.dbus_error_name,
-                "",
-            )
-            error_message.send()
-            return
 
         if not request_message.expect_reply:
             return
