@@ -24,17 +24,11 @@ from typing import TYPE_CHECKING
 from xml.etree.ElementTree import fromstring as etree_from_str
 from xml.etree.ElementTree import parse as etree_from_file
 
+from .dbus_common_funcs import snake_case_to_camel_case
+
 if TYPE_CHECKING:
-    from typing import (
-        Dict,
-        Iterable,
-        Iterator,
-        List,
-        Literal,
-        Optional,
-        Tuple,
-        Union,
-    )
+    from collections.abc import Iterable, Iterator
+    from typing import Literal, Optional, Union
     from xml.etree.ElementTree import Element
 
 
@@ -142,11 +136,11 @@ class DbusSigToTyping:
 
     @staticmethod
     def typing_into_tuple(typing_iter: Iterable[str]) -> str:
-        return f"Tuple[{', '.join(typing_iter)}]"
+        return f"tuple[{', '.join(typing_iter)}]"
 
     @staticmethod
     def slice_container(dbus_sig_iter: Iterator[str], peek_str: str) -> str:
-        accumulator: List[str] = [peek_str]
+        accumulator: list[str] = [peek_str]
         round_braces_count = 0
         curly_braces_count = 0
 
@@ -186,8 +180,8 @@ class DbusSigToTyping:
         return ''.join(accumulator)
 
     @classmethod
-    def split_sig(cls, sig: str) -> List[str]:
-        completes: List[str] = []
+    def split_sig(cls, sig: str) -> list[str]:
+        completes: list[str] = []
 
         sig_iter = iter(sig)
 
@@ -225,7 +219,7 @@ class DbusSigToTyping:
             dict_value_sig = complete_sig[3:-1]
             dict_value_typing = cls.typing_complete(dict_value_sig)
 
-            return f"Dict[{dict_key_typing}, {dict_value_typing}]"
+            return f"dict[{dict_key_typing}, {dict_value_typing}]"
 
         elif complete_sig.startswith('a'):
             array_completes = cls.split_sig(complete_sig[1:])
@@ -236,7 +230,7 @@ class DbusSigToTyping:
 
             array_single_complete = array_completes[0]
 
-            return f"List[{cls.typing_complete(array_single_complete)}]"
+            return f"list[{cls.typing_complete(array_single_complete)}]"
         elif complete_sig.startswith('('):
             if complete_sig[-1] != ')':
                 raise ValueError(f"Malformed struct {complete_sig}")
@@ -249,7 +243,7 @@ class DbusSigToTyping:
             return cls.typing_basic(complete_sig)
 
     @classmethod
-    def result_typing(cls, result_args: List[str]) -> str:
+    def result_typing(cls, result_args: list[str]) -> str:
         result_len = len(result_args)
 
         if result_len == 0:
@@ -258,7 +252,7 @@ class DbusSigToTyping:
             return cls.typing_complete(result_args[0])
         else:
             return cls.typing_into_tuple(
-                (cls.typing_complete(x) for x in result_args)
+                cls.typing_complete(x) for x in result_args
             )
 
     @classmethod
@@ -325,6 +319,10 @@ class DbusMemberAbstract:
                 raise ValueError(
                     'Uknown member annotation tag: ', tag)
 
+    @property
+    def wants_rename(self) -> bool:
+        return self.method_name != snake_case_to_camel_case(self.python_name)
+
 
 class DbusArgsIntrospection:
     def __init__(self, element: Element):
@@ -365,8 +363,8 @@ class DbusMethodInrospection(DbusMemberAbstract):
 
         self.is_no_reply = False
 
-        self.input_args: List[DbusArgsIntrospection] = []
-        self.result_args: List[DbusArgsIntrospection] = []
+        self.input_args: list[DbusArgsIntrospection] = []
+        self.result_args: list[DbusArgsIntrospection] = []
 
         super().__init__(element)
 
@@ -388,19 +386,19 @@ class DbusMethodInrospection(DbusMemberAbstract):
     @property
     def dbus_input_signature(self) -> str:
         return ''.join(
-            (x.dbus_type for x in self.input_args)
+            x.dbus_type for x in self.input_args
         )
 
     @property
     def dbus_result_signature(self) -> str:
         return ''.join(
-            (x.dbus_type if not x.is_input else ''
-             for x in self.result_args)
+            x.dbus_type if not x.is_input else ''
+            for x in self.result_args
         )
 
     @property
-    def args_names_and_typing(self) -> List[Tuple[str, str]]:
-        arg_names: List[Tuple[str, str]] = []
+    def args_names_and_typing(self) -> list[tuple[str, str]]:
+        arg_names: list[tuple[str, str]] = []
 
         for i, input_arg in enumerate(self.input_args):
             if input_arg.name is not None:
@@ -419,7 +417,7 @@ class DbusMethodInrospection(DbusMemberAbstract):
 
     @property
     def is_results_args_valid_names(self) -> bool:
-        return all((r.name is not None for r in self.result_args))
+        return all(r.name is not None for r in self.result_args)
 
     @property
     def result_args_names_repr(self) -> str:
@@ -432,7 +430,7 @@ class DbusMethodInrospection(DbusMemberAbstract):
 
 
 class DbusPropertyIntrospection(DbusMemberAbstract):
-    _EMITS_CHANGED_MAP: Dict[
+    _EMITS_CHANGED_MAP: dict[
         Union[bool, Literal['const', 'invalidates']], str
     ] = {
         True: 'DbusPropertyEmitsChangeFlag',
@@ -504,7 +502,7 @@ class DbusSignalIntrospection(DbusMemberAbstract):
         if element.tag != 'signal':
             raise ValueError(f"Expected signal tag, got {element.tag}")
 
-        self.args: List[DbusArgsIntrospection] = []
+        self.args: list[DbusArgsIntrospection] = []
         super().__init__(element)
 
     def _can_use_unpivileged(self) -> bool:
@@ -520,7 +518,7 @@ class DbusSignalIntrospection(DbusMemberAbstract):
 
     @property
     def dbus_signature(self) -> str:
-        return ''.join((x.dbus_type for x in self.args))
+        return ''.join(x.dbus_type for x in self.args)
 
     @property
     def typing(self) -> str:
@@ -529,7 +527,7 @@ class DbusSignalIntrospection(DbusMemberAbstract):
 
     @property
     def is_args_valid_names(self) -> bool:
-        return all((a.name is not None for a in self.args))
+        return all(a.name is not None for a in self.args)
 
     @property
     def args_names_repr(self) -> str:
@@ -548,9 +546,9 @@ class DbusInterfaceIntrospection:
         self.is_deprecated = False
         self.c_name: Optional[str] = None
 
-        self.methods: List[DbusMethodInrospection] = []
-        self.properties: List[DbusPropertyIntrospection] = []
-        self.signals: List[DbusSignalIntrospection] = []
+        self.methods: list[DbusMethodInrospection] = []
+        self.properties: list[DbusPropertyIntrospection] = []
+        self.signals: list[DbusSignalIntrospection] = []
         for dbus_member in element:
             if dbus_member.tag == 'method':
                 self.methods.append(DbusMethodInrospection(dbus_member))
@@ -584,7 +582,7 @@ SKIP_INTERFACES = {
 }
 
 
-INTERFACE_TEMPLATES: Dict[str, str] = {
+INTERFACE_TEMPLATES: dict[str, str] = {
     "generic_no_members": """\
 ...  # Interface has no members
 """,
@@ -596,12 +594,12 @@ input_signature="{{ method.dbus_input_signature }}",
 {% if method.dbus_result_signature %}
 result_signature="{{ method.dbus_result_signature }}",
 {% endif %}
-{% if method.is_results_args_valid_names %}
-result_args_names={{method.result_args_names_repr}},
-{% endif %}
 {% if method.flags_str %}
 flags={{ method.flags_str }},
 {% endif %}
+{% if method.wants_rename %}
+method_name="{{method.method_name}}",
+{% endif %}
 """
     ),
     "generic_property_flags": (
@@ -612,12 +610,15 @@ property_signature="{{ a_property.dbus_signature }}",
 {% if a_property.flags_str %}
 flags={{ a_property.flags_str }},
 {% endif %}
+{% if a_property.wants_rename %}
+property_name="{{a_property.method_name}}",
+{% endif %}
 """
     ),
     "generic_header": """\
 from __future__ import annotations
 
-from typing import Any, Dict, List, Tuple
+from typing import Any
 
 """,
     "async_imports_header": """from sdbus import (
@@ -682,6 +683,9 @@ class {{ interface.python_name }}(
 {% filter indent(first=True) %}
     {% include 'generic_method_flags' %}
 {% endfilter %}
+{% if method.is_results_args_valid_names %}
+    result_args_names={{method.result_args_names_repr}},
+{% endif %}
 )
 async def {{ method.python_name }}(
     self,
@@ -717,6 +721,9 @@ def {{ a_property.python_name }}(self) -> {{ a_property.typing }}:
 {% if signal.flags_str %}
     flags={{ signal.flags_str }},
 {% endif %}
+{% if signal.wants_rename %}
+    signal_name=signal.method_name,
+{% endif %}
 )
 def {{ signal.python_name }}(self) -> {{ signal.typing }}:
     raise NotImplementedError
@@ -809,9 +816,9 @@ def {{ a_property.python_name }}(self) -> {{ a_property.typing }}:
 
 
 def xml_to_interfaces_introspection(
-        root: Element) -> List[DbusInterfaceIntrospection]:
+        root: Element) -> list[DbusInterfaceIntrospection]:
 
-    list_of_interface_introspection: List[DbusInterfaceIntrospection] = []
+    list_of_interface_introspection: list[DbusInterfaceIntrospection] = []
 
     if root.tag != 'node':
         raise ValueError(f"Expected node tag got {root.tag}")
@@ -830,14 +837,14 @@ def xml_to_interfaces_introspection(
 
 
 def interfaces_from_file(filename_or_path: Union[str, Path]
-                         ) -> List[DbusInterfaceIntrospection]:
+                         ) -> list[DbusInterfaceIntrospection]:
 
     etree = etree_from_file(filename_or_path)
 
     return xml_to_interfaces_introspection(etree.getroot())
 
 
-def interfaces_from_str(xml_str: str) -> List[DbusInterfaceIntrospection]:
+def interfaces_from_str(xml_str: str) -> list[DbusInterfaceIntrospection]:
 
     etree = etree_from_str(xml_str)
 
@@ -845,7 +852,7 @@ def interfaces_from_str(xml_str: str) -> List[DbusInterfaceIntrospection]:
 
 
 def generate_py_file(
-    interfaces: List[DbusInterfaceIntrospection],
+    interfaces: list[DbusInterfaceIntrospection],
     include_import_header: bool = True,
     do_async: bool = True,
 ) -> str:
