@@ -20,11 +20,23 @@
 */
 #include <errno.h>
 #include <poll.h>
+#include <sys/timerfd.h>
+#include <time.h>
 #include "sd_bus_internals.h"
 
 static void SdBus_dealloc(SdBusObject* self) {
+        if (NULL != self->loop && NULL != self->bus_fd) {
+                Py_XDECREF(PyObject_CallMethodObjArgs(self->loop, remove_reader_str, self->bus_fd, NULL));
+                Py_XDECREF(PyObject_CallMethodObjArgs(self->loop, remove_writer_str, self->bus_fd, NULL));
+        }
+        if (NULL != self->timer_fd) {
+                Py_XDECREF(PyObject_CallMethodObjArgs(self->loop, remove_reader_str, self->timer_fd, NULL));
+                Py_DECREF(self->timer_fd);
+                close(self->timer_fd_int);
+        }
         sd_bus_unref(self->sd_bus_ref);
         Py_XDECREF(self->bus_fd);
+        Py_XDECREF(self->loop);
 
         SD_BUS_DEALLOC_TAIL;
 }
@@ -240,6 +252,13 @@ static PyObject* SdBus_asyncio_update_fd_watchers(SdBusObject* self);
 
 #define CHECK_ASYNCIO_WATCHERS ({ CALL_PYTHON_EXPECT_NONE(SdBus_asyncio_update_fd_watchers(self)); })
 
+static PyObject* _get_or_bind_loop(SdBusObject* self) {
+        if (NULL == self->loop) {
+                self->loop = CALL_PYTHON_AND_CHECK(PyObject_CallFunctionObjArgs(asyncio_get_running_loop, NULL));
+        }
+        return self->loop;
+}
+
 static PyObject* SdBus_process(SdBusObject* self, PyObject* Py_UNUSED(args)) {
         int return_value = 1;
         while (return_value > 0) {
@@ -308,7 +327,7 @@ static PyObject* SdBus_call_async(SdBusObject* self, PyObject* args) {
         SdBusMessageObject* call_message = NULL;
         CALL_PYTHON_BOOL_CHECK(PyArg_ParseTuple(args, "O", &call_message, NULL));
 #endif
-        PyObject* running_loop CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_CallFunctionObjArgs(asyncio_get_running_loop, NULL));
+        PyObject* running_loop = CALL_PYTHON_AND_CHECK(_get_or_bind_loop(self));
 
         PyObject* new_future = CALL_PYTHON_AND_CHECK(PyObject_CallMethod(running_loop, "create_future", ""));
 
@@ -421,7 +440,7 @@ static PyObject* SdBus_match_signal_async(SdBusObject* self, PyObject* args) {
         CALL_PYTHON_BOOL_CHECK(PyArg_ParseTuple(args, "zzzzO", &sender_service_char_ptr, &path_name_char_ptr, &interface_name_char_ptr, &member_name_char_ptr,
                                                 &signal_callback, NULL));
 #endif
-        PyObject* running_loop CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_CallFunctionObjArgs(asyncio_get_running_loop, NULL));
+        PyObject* running_loop = CALL_PYTHON_AND_CHECK(_get_or_bind_loop(self));
         PyObject* new_future CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_CallMethod(running_loop, "create_future", ""));
 
         SdBusSlotObject* new_slot CLEANUP_SD_BUS_SLOT = (SdBusSlotObject*)CALL_PYTHON_AND_CHECK(SD_BUS_PY_CLASS_DUNDER_NEW(SdBusSlot_class));
@@ -503,7 +522,7 @@ static PyObject* SdBus_request_name_async(SdBusObject* self, PyObject* args) {
         CALL_PYTHON_BOOL_CHECK(PyArg_ParseTuple(args, "sK", &service_name_char_ptr, &flags_long_long, NULL));
         uint64_t flags = (uint64_t)flags_long_long;
 #endif
-        PyObject* running_loop CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_CallFunctionObjArgs(asyncio_get_running_loop, NULL));
+        PyObject* running_loop = CALL_PYTHON_AND_CHECK(_get_or_bind_loop(self));
         PyObject* new_future = CALL_PYTHON_AND_CHECK(PyObject_CallMethod(running_loop, "create_future", ""));
         SdBusSlotObject* new_slot_object CLEANUP_SD_BUS_SLOT = (SdBusSlotObject*)CALL_PYTHON_AND_CHECK(SD_BUS_PY_CLASS_DUNDER_NEW(SdBusSlot_class));
 
@@ -607,6 +626,14 @@ static PyObject* SdBus_emit_object_removed(SdBusObject* self, PyObject* args) {
 
 static PyObject* SdBus_close(SdBusObject* self, PyObject* Py_UNUSED(args)) {
         sd_bus_close(self->sd_bus_ref);
+        if (NULL != self->loop && NULL != self->bus_fd) {
+                Py_XDECREF(CALL_PYTHON_AND_CHECK(PyObject_CallMethodObjArgs(self->loop, remove_reader_str, self->bus_fd, NULL)));
+                Py_XDECREF(CALL_PYTHON_AND_CHECK(PyObject_CallMethodObjArgs(self->loop, remove_writer_str, self->bus_fd, NULL)));
+        }
+        if (NULL != self->timer_fd) {
+                Py_XDECREF(PyObject_CallMethodObjArgs(self->loop, remove_reader_str, self->timer_fd, NULL));
+                // TODO: Close timerfd
+        }
         Py_RETURN_NONE;
 }
 
@@ -623,7 +650,45 @@ static inline int sd_bus_get_events_zero_on_closed(SdBusObject* self) {
         return events;
 };
 
+static inline int sd_bus_get_timeout_uint_max_on_closed(SdBusObject* self, uint64_t* timeout_usec) {
+        int r = sd_bus_get_timeout(self->sd_bus_ref, timeout_usec);
+        if (-ENOTCONN == r) {
+                *timeout_usec = UINT64_MAX;
+                return 0;
+        }
+        return r;
+}
+
 static PyObject* SdBus_asyncio_update_fd_watchers(SdBusObject* self) {
+        PyObject* running_loop = CALL_PYTHON_AND_CHECK(_get_or_bind_loop(self));
+        PyObject* drive_method CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_GetAttrString((PyObject*)self, "process"));
+
+        if (NULL == self->timer_fd) {
+                self->timer_fd_int = CALL_SD_BUS_AND_CHECK(timerfd_create(CLOCK_MONOTONIC, TFD_NONBLOCK | TFD_CLOEXEC));
+                if (self->timer_fd_int < 0) {
+                        PyErr_SetFromErrno(PyExc_OSError);
+                }
+                PyObject* timer_fd CLEANUP_PY_OBJECT = PyLong_FromLong((int)self->timer_fd_int);
+                Py_XDECREF(CALL_PYTHON_AND_CHECK(PyObject_CallMethodObjArgs(running_loop, add_reader_str, timer_fd, drive_method, NULL)));
+                Py_INCREF(timer_fd);
+                self->timer_fd = timer_fd;
+        }
+
+        uint64_t timeout_usec = UINT64_MAX;
+        CALL_SD_BUS_AND_CHECK(sd_bus_get_timeout_uint_max_on_closed(self, &timeout_usec));
+
+        struct itimerspec bus_timer = {0};
+        if (timeout_usec == UINT64_MAX) {
+                // Setting bus_timer to zero disarms timer.
+        } else if (timeout_usec != 0) {
+                bus_timer.it_value.tv_sec = timeout_usec / 1000000;
+                bus_timer.it_value.tv_nsec = (timeout_usec % 1000000) * 1000;
+        } else if (timeout_usec == 0) {
+                Py_XDECREF(CALL_PYTHON_AND_CHECK(PyObject_CallMethodObjArgs(running_loop, call_soon_str, drive_method, NULL)));
+        }
+
+        CALL_SD_BUS_AND_CHECK(timerfd_settime(self->timer_fd_int, TFD_TIMER_ABSTIME, &bus_timer, NULL));
+
         int events_to_watch = CALL_SD_BUS_AND_CHECK(sd_bus_get_events_zero_on_closed(self));
         if (events_to_watch == self->asyncio_watchers_last_state) {
                 // Do not update the watchers because state is the same
@@ -632,9 +697,6 @@ static PyObject* SdBus_asyncio_update_fd_watchers(SdBusObject* self) {
                 self->asyncio_watchers_last_state = events_to_watch;
         }
 
-        PyObject* running_loop CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_CallFunctionObjArgs(asyncio_get_running_loop, NULL));
-        PyObject* drive_method CLEANUP_PY_OBJECT = CALL_PYTHON_AND_CHECK(PyObject_GetAttrString((PyObject*)self, "process"));
-
         if (NULL == self->bus_fd) {
                 self->bus_fd = CALL_PYTHON_AND_CHECK(SdBus_get_fd(self, NULL));
         }
