@@ -54,8 +54,6 @@ from sdbus import (
 )
 
 if TYPE_CHECKING:
-    from typing import Tuple
-
     from sdbus.dbus_proxy_async_interfaces import (
         DBUS_PROPERTIES_CHANGED_TYPING,
     )
@@ -173,7 +171,7 @@ class TestInterface(
             return input.lower()
 
     @dbus_signal_async('ss')
-    def test_signal(self) -> Tuple[str, str]:
+    def test_signal(self) -> tuple[str, str]:
         """Test signal"""
         raise NotImplementedError
 
@@ -198,6 +196,10 @@ class TestInterface(
 
         raise DbusErrorUnmappedLater('Should be unmapped')
 
+    @dbus_method_async()
+    async def raise_python_exc(self) -> None:
+        raise ValueError("Test!")
+
     @dbus_method_async('s', flags=DbusNoReplyFlag)
     async def no_reply_method(self, new_value: str) -> None:
         self.no_reply_sync.set()
@@ -209,13 +211,13 @@ class TestInterface(
     @dbus_method_async(
         result_signature='(ss)'
     )
-    async def test_struct_return(self) -> Tuple[str, str]:
+    async def test_struct_return(self) -> tuple[str, str]:
         return ('hello', 'world')
 
     @dbus_method_async(
         result_signature='(ss)'
     )
-    async def test_struct_return_workaround(self) -> Tuple[Tuple[str, str]]:
+    async def test_struct_return_workaround(self) -> tuple[tuple[str, str]]:
         return (('hello', 'world'), )
 
     @dbus_method_async()
@@ -236,7 +238,7 @@ class TestInterface(
     )
     async def takes_struct_method(
         self,
-        int_struct: Tuple[int, int, int, int],
+        int_struct: tuple[int, int, int, int],
     ) -> int:
         a, b, c, d = int_struct
         return a*b*c*d
@@ -257,7 +259,7 @@ class DbusErrorUnmappedLater(DbusFailedError):
 TEST_SERVICE_NAME = 'org.example.test'
 
 
-def initialize_object() -> Tuple[TestInterface, TestInterface]:
+def initialize_object() -> tuple[TestInterface, TestInterface]:
     test_object = TestInterface()
     test_object.export_to_dbus('/')
 
@@ -372,7 +374,6 @@ class TestProxy(IsolatedDbusTestCase):
 
             @test_property.setter
             def test_property_setter(self, var: str) -> None:
-                nonlocal test_var
                 test_var.insert(0, var)
 
         test_subclass = TestInheritence()
@@ -510,7 +511,7 @@ class TestProxy(IsolatedDbusTestCase):
 
         with self.subTest('Catch anywhere over D-Bus object'):
             async def catch_anywhere_oneshot_dbus(
-            ) -> Tuple[str, Tuple[str, str]]:
+            ) -> tuple[str, tuple[str, str]]:
                 async for x in test_object_connection.test_signal\
                         .catch_anywhere():
                     return x
@@ -531,7 +532,7 @@ class TestProxy(IsolatedDbusTestCase):
 
         with self.subTest('Catch anywhere over D-Bus class'):
             async def catch_anywhere_oneshot_from_class(
-            ) -> Tuple[str, Tuple[str, str]]:
+            ) -> tuple[str, tuple[str, str]]:
                 async for x in TestInterface.test_signal.catch_anywhere(
                         TEST_SERVICE_NAME, self.bus):
                     return x
@@ -552,7 +553,7 @@ class TestProxy(IsolatedDbusTestCase):
 
         with self.subTest('Catch anywhere over local object'):
             async def catch_anywhere_oneshot_local(
-            ) -> Tuple[str, Tuple[str, str]]:
+            ) -> tuple[str, tuple[str, str]]:
                 async for x in test_object.test_signal.catch_anywhere():
                     return x
 
@@ -574,13 +575,13 @@ class TestProxy(IsolatedDbusTestCase):
 
         test_tuple = ('sgfsretg', 'asd')
 
-        async def reader_one() -> Tuple[str, str]:
+        async def reader_one() -> tuple[str, str]:
             async for x in test_object_connection.test_signal.catch():
                 return test_tuple
 
             raise RuntimeError
 
-        async def reader_two() -> Tuple[str, str]:
+        async def reader_two() -> tuple[str, str]:
             async for x in test_object_connection.test_signal.catch():
                 return test_tuple
 
@@ -1006,3 +1007,26 @@ class TestProxy(IsolatedDbusTestCase):
 
         with self.assertRaisesRegex(RuntimeError, "different loop"):
             asyncio_run(test())
+
+    async def test_python_exc(self) -> None:
+        test_object, test_object_connection = initialize_object()
+
+        with self.assertRaisesRegex(ValueError, "Test!"):
+            await test_object.raise_python_exc()
+
+        with self.assertRaisesRegex(ValueError, "Test!"):
+            await test_object_connection.raise_python_exc()
+
+    async def test_empty_dbus_interface(self) -> None:
+        class Empty(
+            DbusInterfaceCommonAsync,
+            interface_name="org.empty",
+        ):
+            ...
+
+        empty_local = Empty()
+        empty_local.export_to_dbus("/")
+        empty_proxy = Empty.new_proxy(TEST_SERVICE_NAME, "/")
+
+        intro = await empty_proxy.dbus_introspect()
+        self.assertIn('<interface name="org.empty">', intro)
